fn capped_consensus_cursor_ids(
graph: &BootstrapableGraph,
max_ids: usize,
) -> PreHashSet<BlockId>Expand description
Ids for the reconnect ask: all finals if under the cap, otherwise the newest max_ids by slot.
fn capped_consensus_cursor_ids(
graph: &BootstrapableGraph,
max_ids: usize,
) -> PreHashSet<BlockId>Ids for the reconnect ask: all finals if under the cap, otherwise the newest max_ids by slot.