Function massa_bootstrap::client::shutdown_range
source · fn shutdown_range(
cfg: &BootstrapConfig,
last_start_period: u64,
last_slot_before_downtime: Slot,
) -> Result<(Slot, Slot), BootstrapError>Expand description
Computes the slot range of the last network shutdown, as startup does: from the slot right after the last one executed before the downtime, to the slot right before the restart.